@@ -1,6 +1,7 @@
 from rest_framework.views import exception_handler as exc_handler
 from rest_framework.response import Response
 from django.db import IntegrityError
+from django.core.exceptions import ValidationError
 from rest_framework import status
 
 
@@ -9,5 +10,7 @@ def exception_handler(exc, context):
 
     if isinstance(exc, IntegrityError) and not response:
         response = Response('唯一约束', status=status.HTTP_400_BAD_REQUEST)
+    elif isinstance(exc, ValidationError) and not response:
+        response = Response(exc, status=status.HTTP_400_BAD_REQUEST)
 
     return response
